class GoogleGeoResult {
  List<AddressComponents>? addressComponents;
  String? formattedAddress;
  Geometry? geometry;
  String? placeId;
  PlusCode? plusCode;
  List<String>? types;

  GoogleGeoResult(
      {this.addressComponents,
      this.formattedAddress,
      this.geometry,
      this.placeId,
      this.plusCode,
      this.types});

  GoogleGeoResult.fromJson(Map<String, dynamic> json) {
    addressComponents = json["address_components"] == null
        ? null
        : (json["address_components"] as List)
            .map((e) => AddressComponents.fromJson(e))
            .toList();
    formattedAddress = json["formatted_address"];
    geometry =
        json["geometry"] == null ? null : Geometry.fromJson(json["geometry"]);
    placeId = json["place_id"];
    plusCode =
        json["plus_code"] == null ? null : PlusCode.fromJson(json["plus_code"]);
    types = json["types"] == null ? null : List<String>.from(json["types"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (addressComponents != null) {
      _data["address_components"] =
          addressComponents?.map((e) => e.toJson()).toList();
    }
    _data["formatted_address"] = formattedAddress;
    if (geometry != null) {
      _data["geometry"] = geometry?.toJson();
    }
    _data["place_id"] = placeId;
    if (plusCode != null) {
      _data["plus_code"] = plusCode?.toJson();
    }
    if (types != null) {
      _data["types"] = types;
    }
    return _data;
  }
}

class PlusCode {
  String? compoundCode;
  String? globalCode;

  PlusCode({this.compoundCode, this.globalCode});

  PlusCode.fromJson(Map<String, dynamic> json) {
    compoundCode = json["compound_code"];
    globalCode = json["global_code"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["compound_code"] = compoundCode;
    _data["global_code"] = globalCode;
    return _data;
  }
}

class Geometry {
  Location? location;
  String? locationType;
  Viewport? viewport;

  Geometry({this.location, this.locationType, this.viewport});

  Geometry.fromJson(Map<String, dynamic> json) {
    location =
        json["location"] == null ? null : Location.fromJson(json["location"]);
    locationType = json["location_type"];
    viewport =
        json["viewport"] == null ? null : Viewport.fromJson(json["viewport"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (location != null) {
      _data["location"] = location?.toJson();
    }
    _data["location_type"] = locationType;
    if (viewport != null) {
      _data["viewport"] = viewport?.toJson();
    }
    return _data;
  }
}

class Viewport {
  Northeast? northeast;
  Southwest? southwest;

  Viewport({this.northeast, this.southwest});

  Viewport.fromJson(Map<String, dynamic> json) {
    northeast = json["northeast"] == null
        ? null
        : Northeast.fromJson(json["northeast"]);
    southwest = json["southwest"] == null
        ? null
        : Southwest.fromJson(json["southwest"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (northeast != null) {
      _data["northeast"] = northeast?.toJson();
    }
    if (southwest != null) {
      _data["southwest"] = southwest?.toJson();
    }
    return _data;
  }
}

class Southwest {
  double? lat;
  double? lng;

  Southwest({this.lat, this.lng});

  Southwest.fromJson(Map<String, dynamic> json) {
    lat = json["lat"];
    lng = json["lng"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["lat"] = lat;
    _data["lng"] = lng;
    return _data;
  }
}

class Northeast {
  double? lat;
  double? lng;

  Northeast({this.lat, this.lng});

  Northeast.fromJson(Map<String, dynamic> json) {
    lat = json["lat"];
    lng = json["lng"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["lat"] = lat;
    _data["lng"] = lng;
    return _data;
  }
}

class Location {
  double? lat;
  double? lng;

  Location({this.lat, this.lng});

  Location.fromJson(Map<String, dynamic> json) {
    lat = json["lat"];
    lng = json["lng"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["lat"] = lat;
    _data["lng"] = lng;
    return _data;
  }
}

class AddressComponents {
  String? longName;
  String? shortName;
  List<String>? types;

  AddressComponents({this.longName, this.shortName, this.types});

  AddressComponents.fromJson(Map<String, dynamic> json) {
    longName = json["long_name"];
    shortName = json["short_name"];
    types = json["types"] == null ? null : List<String>.from(json["types"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["long_name"] = longName;
    _data["short_name"] = shortName;
    if (types != null) {
      _data["types"] = types;
    }
    return _data;
  }
}
