import 'package:_private_core_network/utils.dart';
import 'package:dio/dio.dart';

import '../resources.dart';
import 'models/language_available.dart';

class MyAppEndpoint {
  MyAppEndpoint._();
  static String getLanguageAvailableByKeyword() =>
      "v2/ooh/getLanguageAvailableByKeyword";
  static String getLanguagesOfCountry() => "v2/country/getLanguagesOfCountry";
}

abstract class MyAppApi {
  Future<NetworkResponse> getLanguageAvailableByKeyword(params);
  Future<NetworkResponse> getLanguagesOfCountry(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getLanguageAvailableByKeyword(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient().get(
            MyAppEndpoint.getLanguageAvailableByKeyword(),
            queryParameters: params);
        return NetworkResponse.fromResponse(
          response,
          converter: (json) =>
              (json as List).map((e) => LanguageAvailable.fromJson(e)).toList(),
        );
      },
    );
  }

  @override
  Future<NetworkResponse> getLanguagesOfCountry(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient().get(
            MyAppEndpoint.getLanguagesOfCountry(),
            queryParameters: params);
        return NetworkResponse.fromResponse(
          response,
          converter: (json) =>
              (json as List).map((e) => LanguageAvailable.fromJson(e)).toList(),
        );
      },
    );
  }
}
