enum LocationType { home, work, other }

class LocationModel {
  int? id;
  String? uniqueId;
  late String locationLabel;
  late int favourite;
  late String street;
  String? zip;
  late String city;
  late String state;
  late String country;
  String? utcModifier;
  late double lat;
  late double lng;
  late LocationType type;
  late String contactPhone;
  late bool setAsDefault;
  late String deliveryInstructions;

  LocationModel(
      {this.id,
      this.uniqueId,
      this.locationLabel = '',
      this.favourite = 0,
      this.street = "",
      this.zip,
      this.city = "",
      this.state = "",
      this.country = "",
      this.utcModifier = "Europe/Tallinn",
      this.lat = 0,
      this.lng = 0,
      this.type = LocationType.home,
      this.contactPhone = '',
      this.deliveryInstructions = '',
      this.setAsDefault = false});

  LocationModel.fromJson(Map<String, dynamic> json) {
    id = json['locationId'] ?? 0;
    uniqueId = json['uniqueId'] ?? '';
    locationLabel = json['locationLabel'] ?? '';
    favourite = json['favourite'] ?? 0;
    street = json['street'] ?? '';
    zip = json['zip'] ?? '';
    city = json['city'] ?? '';
    state = json['state'] ?? '';
    country = json['country'] ?? '';
    utcModifier = json['utcModifier'] ?? '';
    lat = json['lat'] ?? 0;
    lng = json['lng'] ?? 0;
    type = LocationType.values[json['type'] ?? 0];
    contactPhone = json['contactPhone'] ?? '';
    deliveryInstructions = json['deliveryInstructions'] ?? '';
    setAsDefault = json['setAsDefault'] == 1;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['locationId'] = id;
    data['uniqueId'] = uniqueId;
    data['locationLabel'] = locationLabel;
    data['favourite'] = favourite;
    data['street'] = street;
    data['zip'] = zip;
    data['city'] = city;
    data['state'] = state;
    data['country'] = country;
    data['utcModifier'] = utcModifier;
    data['lat'] = lat;
    data['lng'] = lng;
    data['type'] = type.index;
    data['setAsDefault'] = setAsDefault ? 1 : 0;
    data['contactPhone'] = contactPhone;
    data['deliveryInstructions'] = deliveryInstructions;
    return data;
  }

  @override
  String toString() {
    return "$street\n$city\n$state\n$country";
  }

  String toAddressString() {
    return "$street, $city, $state, $country";
  }

  String toAddressString2() {
    return "$street\n$city${zip != null && zip!.isNotEmpty ? ' $zip' : ''}, \n$state, $country";
  }

  String toAddress2String() {
    if (zip!.isNotEmpty) {
      return '$street\n$zip $city\n$country';
    } else {
      return '$street\n$city\n$country';
    }
  }

  String toAddress3String() {
    return '$country\n$zip $city\n$street';
  }
}
