import '_model.dart';

class ProsModel {
  late int id;
  late String firstName;
  late String lastName;
  late String displayName;
  late String firebaseId;
  late int allowChat;
  late String thumbnail;
  late int favorite;
  late String uniqueId;
  late List<SubCatModel> subCats;
  int? serviceTypeId;
  String? utcModifier;
  String? serviceName;
  int? nextTime;
  int? actualDistance;
  List? fCMTokens;
  late double rating;
  int? score;
  int? timeBeforeStartTracking;

  bool favoritePressing = false; 

  //Value to enable animation create
  bool enableAnimation = true;

  ProsModel(
      {required this.id,
      required this.firstName,
      required this.lastName,
      required this.rating,
      required this.firebaseId,
      required this.displayName,
      required this.uniqueId,
      required this.thumbnail,
      required this.subCats,
      this.utcModifier,
      this.serviceName,
      this.fCMTokens,
      this.allowChat = 1,
      this.favorite = 0,
      this.nextTime,
      this.actualDistance});

  ProsModel.fromJson(Map<String, dynamic> json) {
    id = json['id'] ?? json['proId'] ?? 0;
    firstName = json['firstName'] ?? '';
    lastName = json['lastName'] ?? '';
    rating = json['rating'] == null
        ? -1
        : json['rating'] is String
            ? double.parse(json['rating'])
            : json['rating'];
    displayName = json['displayName'] ?? '';
    firebaseId = json['firebaseId'] ?? '';
    allowChat = json['allowChat'] ?? 1;
    thumbnail = json['thumbnail'] ?? '';
    favorite = json['favorite'] ?? 0;
    fCMTokens = json['fcmToken'];
    uniqueId = json['uniqueId'] ?? json['proUniqueId'] ?? '';
    serviceTypeId = json['serviceTypeId'] ?? 0;
    serviceName = json['serviceName'] ?? '';
    actualDistance = json['actualDistance'];
    utcModifier = json['utcModifier'];
    timeBeforeStartTracking = json['timeBeforeStartTracking'] ?? 0;
    //Debugging
    // nextTime = DateTime.now().add(Duration(seconds: 30)).millisecondsSinceEpoch ~/ 1000;
    nextTime = json['nextTime'] ??
        DateTime.now().add(const Duration(hours: 5)).millisecondsSinceEpoch ~/ 1000;
    subCats = (json['subcat'] ?? [])
        .map<SubCatModel>((e) => SubCatModel.fromJson(e))
        .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['uniqueId'] = uniqueId;
    data['firstName'] = firstName;
    data['lastName'] = lastName;
    data['rating'] = rating;
    data['displayName'] = displayName;
    data['firebaseId'] = firebaseId;
    data['allowChat'] = allowChat;
    data['thumbnail'] = thumbnail;
    data['favorite'] = favorite;
    return data;
  }

  Map<String, dynamic> toJsonSqlite() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['uniqueId'] = uniqueId;
    data['firstName'] = firstName;
    data['lastName'] = lastName;
    data['id'] = id;
    data['displayName'] = displayName;
    data['firebaseId'] = firebaseId;
    data['thumbnail'] = thumbnail;
    return data;
  }
}
