import 'package:_private_core/_private_core.dart';
import '../payment/models/payment_billing_info.dart';
import '_model.dart';

class UserModel {
  int? id;
  String? firebaseId;
  String? username;
  String? tokenFirebase;
  String? token;
  String? uniqueId;
  String? firstName;
  String? lastName;
  String? displayName;
  String? infoName;
  String? phone;
  String? email;
  String? comment;
  String? thumbnail;
  int? blurPicture;
  int? reliability;
  int? createdAt;
  int? signedAt;
  int? allowGeolocation;
  List? fCMTokens;
  int? isTmpEmail;
  int? sellerStatus;
  String? sellerQrCode;
  int? timeBeforeStartTracking;
  dynamic distanceBeforeStartTracking;
  String? interfaceLanguageCode;
  String? dateFormat;
  String? timeFormat;
  List<PaymentBillingInfo>? billingInfos;
  TokenResponseLoginMqtt? mqtt;
  int? processStatus;
  String? aboutMeHomelido;
  String? tagline;
  int? isTmp;
  CommonMedia? banner;
  dynamic rating;

  bool get isUserVersion => true;

  String get fChar => displayName == null || displayName!.isEmpty
      ? ''
      : displayName!.split('').first;

  bool isNotYetSeller([int? status]) {
    status ??= sellerStatus;
    return status != SELLER_STATUS_WAIT_PASSPORT &&
        status != SELLER_STATUS_WAIT_SELFIE &&
        status != SELLER_STATUS_WAIT_REQUEST &&
        status != SELLER_STATUS_WAIT_APPROVE &&
        status != SELLER_STATUS_IS_SELLER &&
        status != SELLER_STATUS_HAS_QUIT_TMP &&
        status != SELLER_STATUS_HAS_QUIT_FOREVER &&
        status != SELLER_STATUS_IS_REJECTED;
  }

  UserModel({
    this.id,
    this.firebaseId,
    this.username,
    this.tokenFirebase,
    this.token,
    this.uniqueId,
    this.firstName,
    this.lastName,
    this.displayName,
    this.infoName,
    this.phone,
    this.email,
    this.comment,
    this.thumbnail = '',
    this.blurPicture = 0,
    this.reliability = 0,
    this.createdAt = 0,
    this.allowGeolocation = 0,
    this.signedAt = 0,
    this.fCMTokens,
    this.isTmpEmail,
    this.sellerStatus,
    this.sellerQrCode,
    this.timeBeforeStartTracking = 0,
    this.interfaceLanguageCode,
    this.distanceBeforeStartTracking,
    this.dateFormat,
    this.timeFormat,
    this.billingInfos,
    this.mqtt,
    this.aboutMeHomelido,
    this.tagline,
    this.isTmp,
    this.processStatus,
    this.banner,
    this.rating,
  });

  UserModel.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    firebaseId = json['firebaseId'] ?? '';
    username = json['username'] ?? '';
    tokenFirebase = json['tokenFirebase'];
    token = json['token'];
    uniqueId = json['uniqueId'];
    firstName = json['firstName'] ?? '';
    lastName = json['lastName'] ?? '';
    displayName = json['displayName'] ?? '';
    infoName = json['infoName'] ?? '';
    phone = json['phone'] ?? '';
    email = json['email'];
    comment = json['comment'];
    thumbnail = json['thumbnail'] ?? '';
    blurPicture = json['blurPicture'];
    reliability = json['reliability'];
    createdAt = json['createdAt'];
    signedAt = json['signedAt'];
    fCMTokens = json['fcmToken'];
    allowGeolocation = json['allowGeolocation'];
    isTmpEmail = json['isTmpEmail'];
    sellerStatus = json['sellerStatus'];
    sellerQrCode = json['sellerQrCode'] ?? "";
    timeBeforeStartTracking = json['timeBeforeStartTracking'] ?? 0;
    interfaceLanguageCode = json['interfaceLanguageCode'];
    distanceBeforeStartTracking = json['distanceBeforeStartTracking'] ?? 0.0;
    dateFormat = json['dateFormat'];
    timeFormat = json['timeFormat'];
    if (json["billingInfos"] is List) {
      billingInfos = (json["billingInfos"] as List)
          .map((e) => PaymentBillingInfo.fromJson(e))
          .toList();
    }

    mqtt = json["mqtt"] == null
        ? null
        : TokenResponseLoginMqtt.fromJson(json["mqtt"]);
    isTmp = json["isTmp"];
    aboutMeHomelido = json["aboutMeHomelido"];
    tagline = json["tagline"];
    processStatus = json["processStatus"];
    if (json["banner"] != null) {
      banner = CommonMedia.fromJson(json["banner"]);
    }
    if (json["rating"] is num) {
      rating = json["rating"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['firebaseId'] = firebaseId;
    data['username'] = username;
    data['tokenFirebase'] = tokenFirebase;
    data['token'] = token;
    data['uniqueId'] = uniqueId;
    data['firstName'] = firstName;
    data['lastName'] = lastName;
    data['displayName'] = displayName;
    data['infoName'] = infoName;
    data['phone'] = phone;
    data['email'] = email;
    data['comment'] = comment;
    data['thumbnail'] = thumbnail;
    data['blurPicture'] = blurPicture;
    data['reliability'] = reliability;
    data['createdAt'] = createdAt;
    data['signedAt'] = signedAt;
    data['allowGeolocation'] = allowGeolocation;
    data['isTmpEmail'] = isTmpEmail;
    data['sellerStatus'] = sellerStatus;
    data['sellerQrCode'] = sellerQrCode;
    data['timeBeforeStartTracking'] = timeBeforeStartTracking;
    data['interfaceLanguageCode'] = interfaceLanguageCode;
    data['distanceBeforeStartTracking'] = distanceBeforeStartTracking;
    data['dateFormat'] = dateFormat;
    data['timeFormat'] = timeFormat;
    data["aboutMeHomelido"] = aboutMeHomelido;
    data["tagline"] = tagline;
    data["processStatus"] = processStatus;
    data["rating"] = rating;
    data["isTmp"] = isTmp;
    data["banner"] = banner?.toJson();
    return data;
  }

  Map<String, dynamic> toJsonSqlite() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['uniqueId'] = uniqueId;
    data['firstName'] = firstName;
    data['lastName'] = lastName;
    data['id'] = id;
    data['displayName'] = displayName;
    data['firebaseId'] = firebaseId;
    data['username'] = username;
    data['thumbnail'] = thumbnail;
    return data;
  }
}

class GetUserDetailModel {
  GetUserDetailModel({
    required this.userInfo,
  });

  UserModel userInfo;

  factory GetUserDetailModel.fromJson(Map<String, dynamic> json) =>
      GetUserDetailModel(
        userInfo: UserModel.fromJson(json["values"]),
      );

  Map<String, dynamic> toJson() => {
        "values": userInfo.toJson(),
      };
}

class ProInfo {
  int? id;
  String? firebaseId;
  String? username;
  String? token;
  String? uniqueId;
  String? firstName;
  String? lastName;
  String? displayName;
  String? website;
  String? categorie;
  String? profession;
  dynamic rating;
  String? email;
  String? phone1;
  String? phone2;
  String? street1;
  String? street2;
  String? companyName;
  String? zip;
  String? city;
  String? state;
  String? country;
  String? countryCode;
  double? lat;
  double? lng;
  String? colorCode;
  String? thumbnail;
  int? createdAt;
  int? signedAt;
  String? google;
  String? facebook;
  String? twitter;
  String? pinterest;
  String? instagram;
  String? linkedin;
  String? aboutMe;
  int? google2FaFlg;
  String? google2FaSecretKey;
  int? usedStorageSpace;
  String? gender;
  String? ageRange;
  String? phoneCode;
  String? subscriptionPlanId;
  int? allowChat;
  String? planName;
  String? mainLanguage;
  String? interfaceLanguageCode;
  List<dynamic>? secondaryLanguages;
  int? reliability;
  int? events;
  String? organisation;
  String? roleName;
  List<dynamic>? permissions;
  int? smsAllowed;
  int? freeSms;
  String? currency;
  String? billingName;
  String? vatNumber;
  String? companyNumber;
  String? organisationThumbnail;
  int? timeBeforeStartTracking;
  int? distanceBeforeStartTracking;
  String? registerFrom;
  int? isHomelidoAgent;
  int? industryId;
  int? allowGeolocation;
  String? dateFormat;
  String? timeFormat;
  MainSubcatInfo? mainSubcatInfo;
  String? industryName;
  String? kisblePublicThumbnailUrl;
  String? internalArckipelNote;
  List<PaymentBillingInfo>? billingInfos;
  TokenResponseLoginMqtt? mqtt;
  String? whiseClientId;
  int? processStatus;
  String? aboutMeHomelido;
  String? tagline;
  int? isTmp;
  CommonMedia? banner;

  bool get isUserVersion => false;

  String get fChar => displayName == null || displayName!.isEmpty
      ? ''
      : displayName!.split('').first;

  ProInfo({
    this.id,
    this.firebaseId,
    this.username,
    this.token,
    this.uniqueId,
    this.firstName,
    this.lastName,
    this.displayName,
    this.website,
    this.categorie,
    this.profession,
    this.rating,
    this.email,
    this.phone1,
    this.phone2,
    this.street1,
    this.street2,
    this.companyName,
    this.zip,
    this.city,
    this.state,
    this.country,
    this.countryCode,
    this.lat,
    this.lng,
    this.colorCode,
    this.thumbnail,
    this.createdAt,
    this.signedAt,
    this.google,
    this.facebook,
    this.twitter,
    this.pinterest,
    this.instagram,
    this.linkedin,
    this.aboutMe,
    this.google2FaFlg,
    this.google2FaSecretKey,
    this.usedStorageSpace,
    this.gender,
    this.ageRange,
    this.phoneCode,
    this.subscriptionPlanId,
    this.allowChat,
    this.planName,
    this.mainLanguage,
    this.interfaceLanguageCode,
    this.secondaryLanguages,
    this.reliability,
    this.events,
    this.organisation,
    this.roleName,
    this.permissions,
    this.smsAllowed,
    this.freeSms,
    this.currency,
    this.billingName,
    this.vatNumber,
    this.companyNumber,
    this.organisationThumbnail,
    this.timeBeforeStartTracking,
    this.distanceBeforeStartTracking,
    this.registerFrom,
    this.isHomelidoAgent,
    this.industryId,
    this.allowGeolocation,
    this.dateFormat,
    this.timeFormat,
    this.mainSubcatInfo,
    this.industryName,
    this.billingInfos,
    this.internalArckipelNote,
    this.kisblePublicThumbnailUrl,
    this.mqtt,
    this.whiseClientId,
    this.aboutMeHomelido,
    this.tagline,
    this.isTmp,
    this.processStatus,
    this.banner,
  });

  ProInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["firebaseId"] is String) {
      firebaseId = json["firebaseId"];
    }
    if (json["username"] is String) {
      username = json["username"];
    }
    if (json["token"] is String) {
      token = json["token"];
    }
    if (json["uniqueId"] is String) {
      uniqueId = json["uniqueId"];
    }
    if (json["firstName"] is String) {
      firstName = json["firstName"];
    }
    if (json["lastName"] is String) {
      lastName = json["lastName"];
    }
    if (json["displayName"] is String) {
      displayName = json["displayName"];
    }
    if (json["website"] is String) {
      website = json["website"];
    }
    if (json["categorie"] is String) {
      categorie = json["categorie"];
    }
    if (json["profession"] is String) {
      profession = json["profession"];
    }
    if (json["rating"] is num) {
      rating = json["rating"];
    }
    if (json["email"] is String) {
      email = json["email"];
    }
    if (json["phone1"] is String) {
      phone1 = json["phone1"];
    }
    if (json["phone2"] is String) {
      phone2 = json["phone2"];
    }
    if (json["street1"] is String) {
      street1 = json["street1"];
    }
    if (json["street2"] is String) {
      street2 = json["street2"];
    }
    if (json["companyName"] is String) {
      companyName = json["companyName"];
    }
    if (json["zip"] is String) {
      zip = json["zip"];
    }
    if (json["city"] is String) {
      city = json["city"];
    }
    if (json["state"] is String) {
      state = json["state"];
    }
    if (json["country"] is String) {
      country = json["country"];
    }
    if (json["countryCode"] is String) {
      countryCode = json["countryCode"];
    }
    if (json["lat"] is double) {
      lat = json["lat"];
    }
    if (json["lng"] is double) {
      lng = json["lng"];
    }
    if (json["colorCode"] is String) {
      colorCode = json["colorCode"];
    }
    if (json["thumbnail"] is String) {
      thumbnail = json["thumbnail"];
    }
    if (json["createdAt"] is int) {
      createdAt = json["createdAt"];
    }
    if (json["signedAt"] is int) {
      signedAt = json["signedAt"];
    }
    if (json["google"] is String) {
      google = json["google"];
    }
    if (json["facebook"] is String) {
      facebook = json["facebook"];
    }
    if (json["twitter"] is String) {
      twitter = json["twitter"];
    }
    if (json["pinterest"] is String) {
      pinterest = json["pinterest"];
    }
    if (json["instagram"] is String) {
      instagram = json["instagram"];
    }
    if (json["linkedin"] is String) {
      linkedin = json["linkedin"];
    }
    if (json["aboutMe"] is String) {
      aboutMe = json["aboutMe"];
    }
    if (json["google2FaFlg"] is int) {
      google2FaFlg = json["google2FaFlg"];
    }
    if (json["google2FaSecretKey"] is String) {
      google2FaSecretKey = json["google2FaSecretKey"];
    }
    if (json["usedStorageSpace"] is int) {
      usedStorageSpace = json["usedStorageSpace"];
    }
    if (json["gender"] is String) {
      gender = json["gender"];
    }
    if (json["ageRange"] is String) {
      ageRange = json["ageRange"];
    }
    if (json["phoneCode"] is String) {
      phoneCode = json["phoneCode"];
    }
    if (json["subscriptionPlanId"] is String) {
      subscriptionPlanId = json["subscriptionPlanId"];
    }
    if (json["allowChat"] is int) {
      allowChat = json["allowChat"];
    }
    if (json["planName"] is String) {
      planName = json["planName"];
    }
    if (json["mainLanguage"] is String) {
      mainLanguage = json["mainLanguage"];
    }
    if (json["interfaceLanguageCode"] is String) {
      interfaceLanguageCode = json["interfaceLanguageCode"];
    }
    if (json["secondaryLanguages"] is List) {
      secondaryLanguages = json["secondaryLanguages"] ?? [];
    }
    if (json["reliability"] is int) {
      reliability = json["reliability"];
    }
    if (json["events"] is int) {
      events = json["events"];
    }
    if (json["organisation"] is String) {
      organisation = json["organisation"];
    }
    if (json["roleName"] is String) {
      roleName = json["roleName"];
    }
    if (json["permissions"] is List) {
      permissions = json["permissions"] ?? [];
    }
    if (json["smsAllowed"] is int) {
      smsAllowed = json["smsAllowed"];
    }
    if (json["freeSms"] is int) {
      freeSms = json["freeSms"];
    }
    if (json["currency"] is String) {
      currency = json["currency"];
    }
    if (json["billingName"] is String) {
      billingName = json["billingName"];
    }
    if (json["vatNumber"] is String) {
      vatNumber = json["vatNumber"];
    }
    if (json["companyNumber"] is String) {
      companyNumber = json["companyNumber"];
    }
    if (json["organisationThumbnail"] is String) {
      organisationThumbnail = json["organisationThumbnail"];
    }
    if (json["timeBeforeStartTracking"] is int) {
      timeBeforeStartTracking = json["timeBeforeStartTracking"];
    }
    if (json["distanceBeforeStartTracking"] is int) {
      distanceBeforeStartTracking = json["distanceBeforeStartTracking"];
    }
    if (json["registerFrom"] is String) {
      registerFrom = json["registerFrom"];
    }
    if (json["isHomelidoAgent"] is int) {
      isHomelidoAgent = json["isHomelidoAgent"];
    }
    if (json["industryId"] is int) {
      industryId = json["industryId"];
    }
    if (json["allowGeolocation"] is int) {
      allowGeolocation = json["allowGeolocation"];
    }
    if (json["dateFormat"] is String) {
      dateFormat = json["dateFormat"];
    }
    if (json["timeFormat"] is String) {
      timeFormat = json["timeFormat"];
    }
    if (json["mainSubcatInfo"] is Map) {
      mainSubcatInfo = json["mainSubcatInfo"] == null
          ? null
          : MainSubcatInfo.fromJson(json["mainSubcatInfo"]);
    }
    if (json["industryName"] is String) {
      industryName = json["industryName"];
    }

    if (json["billingInfos"] is List) {
      billingInfos = (json["billingInfos"] as List)
          .map((e) => PaymentBillingInfo.fromJson(e))
          .toList();
    }
    internalArckipelNote = json["internalArckipelNote"];
    whiseClientId = json["whiseClientId"];
    isTmp = json["isTmp"];
    aboutMeHomelido = json["aboutMeHomelido"];
    tagline = json["tagline"];
    processStatus = json["processStatus"];
    if (json["kisblePublicThumbnailUrl"] is String) {
      kisblePublicThumbnailUrl = json["kisblePublicThumbnailUrl"];
    }

    mqtt = json["mqtt"] == null
        ? null
        : TokenResponseLoginMqtt.fromJson(json["mqtt"]);
    if (json["banner"] != null) {
      banner = CommonMedia.fromJson(json["banner"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["firebaseId"] = firebaseId;
    data["username"] = username;
    data["token"] = token;
    data["uniqueId"] = uniqueId;
    data["firstName"] = firstName;
    data["lastName"] = lastName;
    data["displayName"] = displayName;
    data["website"] = website;
    data["categorie"] = categorie;
    data["profession"] = profession;
    data["rating"] = rating;
    data["email"] = email;
    data["phone1"] = phone1;
    data["phone2"] = phone2;
    data["street1"] = street1;
    data["street2"] = street2;
    data["companyName"] = companyName;
    data["zip"] = zip;
    data["city"] = city;
    data["state"] = state;
    data["country"] = country;
    data["countryCode"] = countryCode;
    data["lat"] = lat;
    data["lng"] = lng;
    data["colorCode"] = colorCode;
    data["thumbnail"] = thumbnail;
    data["createdAt"] = createdAt;
    data["signedAt"] = signedAt;
    data["google"] = google;
    data["facebook"] = facebook;
    data["twitter"] = twitter;
    data["pinterest"] = pinterest;
    data["instagram"] = instagram;
    data["linkedin"] = linkedin;
    data["aboutMe"] = aboutMe;
    data["google2FaFlg"] = google2FaFlg;
    data["google2FaSecretKey"] = google2FaSecretKey;
    data["usedStorageSpace"] = usedStorageSpace;
    data["gender"] = gender;
    data["ageRange"] = ageRange;
    data["phoneCode"] = phoneCode;
    data["subscriptionPlanId"] = subscriptionPlanId;
    data["allowChat"] = allowChat;
    data["planName"] = planName;
    data["mainLanguage"] = mainLanguage;
    data["interfaceLanguageCode"] = interfaceLanguageCode;
    if (secondaryLanguages != null) {
      data["secondaryLanguages"] = secondaryLanguages;
    }
    if (billingInfos != null) {
      data["billingInfos"] = billingInfos!.map((e) => e.toJson());
    }
    data["reliability"] = reliability;
    data["events"] = events;
    data["organisation"] = organisation;
    data["roleName"] = roleName;
    if (permissions != null) {
      data["permissions"] = permissions;
    }
    data["smsAllowed"] = smsAllowed;
    data["freeSms"] = freeSms;
    data["currency"] = currency;
    data["billingName"] = billingName;
    data["vatNumber"] = vatNumber;
    data["companyNumber"] = companyNumber;
    data["organisationThumbnail"] = organisationThumbnail;
    data["timeBeforeStartTracking"] = timeBeforeStartTracking;
    data["distanceBeforeStartTracking"] = distanceBeforeStartTracking;
    data["registerFrom"] = registerFrom;
    data["isHomelidoAgent"] = isHomelidoAgent;
    data["industryId"] = industryId;
    data["allowGeolocation"] = allowGeolocation;
    data["dateFormat"] = dateFormat;
    data["timeFormat"] = timeFormat;
    if (mainSubcatInfo != null) {
      data["mainSubcatInfo"] = mainSubcatInfo?.toJson();
    }
    data["industryName"] = industryName;
    data["kisblePublicThumbnailUrl"] = kisblePublicThumbnailUrl;
    data["internalArckipelNote"] = internalArckipelNote;
    data["aboutMeHomelido"] = aboutMeHomelido;
    data["tagline"] = tagline;
    data["processStatus"] = processStatus;
    data["whiseClientId"] = whiseClientId;
    data["isTmp"] = isTmp;
    data["banner"] = banner?.toJson();
    return data;
  }
}

class MainSubcatInfo {
  int? id;
  int? maincatId;
  String? subcatName;
  String? colorCode;
  String? pictureUrl;
  int? display;

  MainSubcatInfo(
      {this.id,
      this.maincatId,
      this.subcatName,
      this.colorCode,
      this.pictureUrl,
      this.display});

  MainSubcatInfo.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["maincatId"] is int) {
      maincatId = json["maincatId"];
    }
    if (json["subcatName"] is String) {
      subcatName = json["subcatName"];
    }
    if (json["colorCode"] is String) {
      colorCode = json["colorCode"];
    }
    if (json["pictureUrl"] is String) {
      pictureUrl = json["pictureUrl"];
    }
    if (json["display"] is int) {
      display = json["display"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["maincatId"] = maincatId;
    data["subcatName"] = subcatName;
    data["colorCode"] = colorCode;
    data["pictureUrl"] = pictureUrl;
    data["display"] = display;
    return data;
  }
}

class GetProDetailModel {
  GetProDetailModel({
    required this.proInfo,
  });

  ProInfo proInfo;

  factory GetProDetailModel.fromJson(Map<String, dynamic> json) =>
      GetProDetailModel(
        proInfo: ProInfo.fromJson(json["values"]),
      );

  Map<String, dynamic> toJson() => {
        "values": proInfo.toJson(),
      };
}
