import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:_private_core_network/utils.dart';
import 'package:dio/dio.dart';

import 'models/payment_billing_info.dart';

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String getBillingInfos() => "v2/payment/getBillingInfos";
  static String updateBillingInfos() => "v2/payment/updateBillingInfos";
  static String deleteBillingInfos() => "v2/payment/deleteBillingInfos";
  static String addBillingInfos() => "v2/payment/addBillingInfos";
  static String setDefaultBillingInfos() => "v2/payment/setDefaultBillingInfos";
}

abstract class MyAppApi {
  Future<NetworkResponse> getBillingInfos(params);
  Future<NetworkResponse> updateBillingInfos(params);
  Future<NetworkResponse> deleteBillingInfos(params);
  Future<NetworkResponse> addBillingInfos(params);
  Future<NetworkResponse> setDefaultBillingInfos(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> addBillingInfos(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response =
            await AppClient(token: await appPrefs.getNormalToken())
                .post(_MyAppEndpoint.addBillingInfos(), data: params);
        return NetworkResponse.fromResponse(response,
            converter: (json) => PaymentBillingInfo.fromJson(json));
      },
    );
  }

  @override
  Future<NetworkResponse> updateBillingInfos(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response =
            await AppClient(token: await appPrefs.getNormalToken())
                .put(_MyAppEndpoint.updateBillingInfos(), data: params);
        return NetworkResponse.fromResponse(response,
            value: response.statusCode == 200);
      },
    );
  }

  @override
  Future<NetworkResponse> setDefaultBillingInfos(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response =
            await AppClient(token: await appPrefs.getNormalToken())
                .put(_MyAppEndpoint.setDefaultBillingInfos(), data: params);
        return NetworkResponse.fromResponse(response,
            value: response.statusCode == 200);
      },
    );
  }

  @override
  Future<NetworkResponse> deleteBillingInfos(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response =
            await AppClient(token: await appPrefs.getNormalToken())
                .put(_MyAppEndpoint.deleteBillingInfos(), data: params);
        return NetworkResponse.fromResponse(response,
            value: response.statusCode == 200);
      },
    );
  }

  @override
  Future<NetworkResponse> getBillingInfos(params) async {
    return await handleNetworkError(
      proccess: () async {
        Response response =
            await AppClient(token: await appPrefs.getNormalToken())
                .get(_MyAppEndpoint.getBillingInfos(), queryParameters: params);
        return NetworkResponse.fromResponse(
          response,
          converter: (json) => (json as List)
              .map((e) => PaymentBillingInfo.fromJson(e))
              .toList(),
        );
      },
    );
  }
}
