
import 'package:_private_core_network/network_resources/resources.dart';

import 'app_api.dart';
import 'models/platform_status_chat.dart';

class PlatformRepo {
  PlatformRepo._();

  static PlatformRepo? _instance;

  factory PlatformRepo([MyAppApi? api]) {
    _instance ??= PlatformRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;
  
  Future<List<PlatformModel>> getPlatformsList([display]) async {
    NetworkResponse response =
        await _api.getPlatformsList({'display': display ?? 1});
    return response.data ?? [];
  }

  Future<List<PlatformModel>> getPlatformsListDoubleAuth([display]) async {
    NetworkResponse response =
        await _api.getPlatformsListDoubleAuth({'display': display ?? 1});
    return response.data ?? [];
  }

  Future<bool> activateDoubleAuthForPlatform(
      {required platformId, doubleAuthActivated = true}) async {
    NetworkResponse response = await _api.activateDoubleAuthForPlatform({
      'platformId': platformId,
      'doubleAuthActivated': doubleAuthActivated ? 1 : 0
    });
    return response.data ?? false;
  }

  Future<List<PlatformStatusChat>> getStatusChatList(params) async {
    NetworkResponse response = await _api.getStatusChatList(params);
    return response.data ?? [];
  }

  Future<PlatformStatusChat?> getMyCurrentStatusChatForPlatformId(
      params) async {
    NetworkResponse response =
        await _api.getMyCurrentStatusChatForPlatformId(params);
    return response.data;
  }

  Future<PlatformStatusChat?> getStatusChatForPlatformId(params) async {
    NetworkResponse response = await _api.getStatusChatForPlatformId(params);
    return response.data;
  }

  Future<bool> updateStatusChatForPlatformId(params) async {
    NetworkResponse response = await _api.updateStatusChatForPlatformId(params);
    return response.data ?? false;
  }

  Future<bool> createChatGroup(params) async {
    NetworkResponse response = await _api.createChatGroup(params);
    return response.data ?? false;
  }

  Future<CommonMedia?> setThumbnailForChatGroup(
      groupId, bytes, filePath) async {
    NetworkResponse response =
        await _api.setThumbnailForChatGroup(groupId, bytes, filePath);
    return response.data;
  }
}
