import 'package:_private_core/_private_core.dart'; 
import '../resources.dart';

class OtherRepo {
  OtherRepo._();

  static OtherRepo? _instance;

  factory OtherRepo([AppApi? api]) {
    _instance ??= OtherRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<List<OnThisDayModel>> birthsOnThisDay(DateTime date) async {
    String _ = '${date.month}/${date.day}';
    NetworkResponse response = await _api.birthsOnThisDay(_);
    return response.data ?? [];
  }

  Future<List<OnThisDayModel>> deathsOnThisDay(DateTime date) async {
    String _ = '${date.month}/${date.day}';
    NetworkResponse response = await _api.deathsOnThisDay(_);
    return response.data ?? [];
  }

  Future<List<OnThisDayModel>> eventsOnThisDay(DateTime date) async {
    String _ = '${date.month}/${date.day}';
    NetworkResponse response = await _api.eventsOnThisDay(_);
    return response.data ?? [];
  }

  Future<List<PexelPhotoModel>> pexelsSearch(
      {String? query,
      String? orientation,
      String? size,
      int per_page = 10}) async {
    NetworkResponse response = await _api.pexelsSearch({
      'query': query ?? 'galaxy',
      'orientation': orientation ?? 'landscape',
      'size': size ?? 'small',
      'per_page': per_page
    });
    return response.data ?? [];
  }

  Future<WeatherForecast?> weatherForecast(
      {double? lat, double? lng, String? location}) async {
    Map<String, dynamic> params = {
      'key': WEATHER_API_KEY,
      'days': 10,
      'aqi': 'no',
      'alerts': 'no'
    };
    if (location != null && location.trim().isNotEmpty) {
      params.addAll({'q': location});
    } else if (lat != null && lng != null) {
      params.addAll({'q': '$lat,$lng'});
    }
    NetworkResponse response = await _api.weatherForecast(params);
    return response.data;
  }

  Future<WeatherForecast?> weatherHistory(
      {required DateTime date,
      double? lat,
      double? lng,
      String? location}) async {
    Map<String, dynamic> params = {
      'key': WEATHER_API_KEY,
      'dt': date.formatDate(formatType: 'yyyy-MM-dd'),
      'aqi': 'no',
      'alerts': 'no'
    };
    if (location != null && location.trim().isNotEmpty) {
      params.addAll({'q': location});
    } else if (lat != null && lng != null) {
      params.addAll({'q': '$lat,$lng'});
    }
    NetworkResponse response = await _api.weatherHistory(params);
    return response.data;
  }

  Future<List<DateFormatModel>> getDateFormatList() async {
    NetworkResponse response = await _api.getDateFormatList();
    return response.data ?? [];
  }

  Future<List<TimeFormatModel>> getTimeFormatList() async {
    NetworkResponse response = await _api.getTimeFormatList();
    return response.data ?? [];
  }

  Future<List<CurrencyAvailable>> getCurrencies() async {
    NetworkResponse response = await _api.getCurrencies();
    return response.data ?? [];
  }

  Future<VideoUrl?> getOowooVideoByTypeId(typeId) async {
    NetworkResponse response = await _api.getOowooVideoByTypeId(typeId);
    return response.data;
  }

  Future<List<AllowedFeatureModel>> getAllowedFeaturesForOowooApp() async {
    NetworkResponse response = await _api.getAllowedFeaturesForOowooApp();
    return response.data ?? [];
  } 

  Future<String?> getTncOowooApp() async {
    NetworkResponse response = await _api.getTncOowooApp();
    return response.data;
  }

  Future<String?> getTncOowooSeller() async {
    NetworkResponse response = await _api.getTncOowooSeller();
    return response.data;
  }

  Future<String?> getLearnMoreTrackingVideo() async {
    NetworkResponse response = await _api.getLearnMoreTrackingVideo();
    return response.data;
  }

  Future<bool> testSendNotificationToPro(
      {required id, required title, required body, required data}) async {
    NetworkResponse response = await _api.testSendNotificationToPro(
        {"body": data, "title": title, "message": body, "pro_id": id});
    return response.data ?? false;
  }

  Future<bool> testSendNotificationToUser(
      {required id, required title, required body, required data}) async {
    NetworkResponse response = await _api.testSendNotificationToUser(
        {"body": data, "title": title, "message": body, "user_id": id});
    return response.data ?? false;
  }

  Future<bool> notifVideoCallProFromUser(
      {required proId, required ticketUniqueId, required notifType}) async {
    NetworkResponse response = await _api.notifVideoCallProFromUser({
      "proId": proId,
      "ticketUniqueId": ticketUniqueId,
      "notifType": notifType
    });
    return response.data ?? false;
  }

  Future<bool> notifVideoCallUserFromPro(
      {required userId, required ticketUniqueId, required notifType}) async {
    NetworkResponse response = await _api.notifVideoCallUserFromPro({
      "userId": userId,
      "ticketUniqueId": ticketUniqueId,
      "notifType": notifType
    });
    return response.data ?? false;
  }

  Future<List<IndustryModel>> getIndustriesList() async {
    NetworkResponse response = await _api.getIndustriesList();
    return response.data ?? [];
  }

  Future<String?> getBgVideo() async {
    NetworkResponse response = await _api.getBgVideo(appPrefs.languageCode);
    return response.data ?? [];
  }

  Future<dynamic> activatePourDevice(deviceId) async {
    NetworkResponse response = await _api.activatePourDevice(deviceId);
    return response.data;
  }

  Future<IpInfo?> ipAPI() async {
    NetworkResponse response = await _api.ipAPI();
    return response.data;
  }

  Future<List<String>> getCurrencyAvailableForToken(tokenType) async {
    NetworkResponse response =
        await _api.getCurrencyAvailableForToken(tokenType);
    return response.data ?? [];
  }

  Future<double> getCurrentTokenValue(tokenType, currency) async {
    NetworkResponse response =
        await _api.getCurrentTokenValue(tokenType, currency: currency);
    return response.data ?? 0.0;
  }

  Future<String?> createFirebaseDynamicLink(params) async {
    NetworkResponse response = await _api.createFirebaseDynamicLink(params);
    return response.data;
  }

  Future<List<RolePro>> getListOfRoles(params) async {
    NetworkResponse response = await _api.getListOfRoles(params);
    return response.data ?? [];
  }

  Future<bool> setProRole(params) async {
    NetworkResponse response = await _api.setProRole(params);
    return response.data ?? false;
  }

  Future<List<ProInfo>> getListOfProsFromAdmin(params) async {
    NetworkResponse response = await _api.getListOfProsFromAdmin(params);
    return response.data ?? [];
  }

  Future<ProInfo?> getProInfosFromSA(params) async {
    NetworkResponse response = await _api.getProInfosFromSA(params);
    return response.data;
  }

  Future<UserModel?> getUserInfosFromSA(params) async {
    NetworkResponse response = await _api.getUserInfosFromSA(params);
    return response.data;
  }

  Future<List<UserModel>> getListOfUsersFromAdmin(params) async {
    NetworkResponse response = await _api.getListOfUsersFromAdmin(params);
    return response.data ?? [];
  }
}
