import 'package:_private_core/_private_core.dart';

import 'package:_private_core_network/network_resources/resources.dart';
import 'package:_private_core_network/utils.dart';
import 'package:dio/dio.dart';
import 'package:dio_cache_interceptor/dio_cache_interceptor.dart';
import 'package:dio_cache_interceptor_hive_store/dio_cache_interceptor_hive_store.dart';

// Global options
final _cacheOptions = CacheOptions(
  // A default store is required for interceptor.
  store: HiveCacheStore(null),

  // All subsequent fields are optional.

  // Default.
  policy: CachePolicy.request,
  // Returns a cached response on error but for statuses 401 & 403.
  // Also allows to return a cached response on network errors (e.g. offline usage).
  // Defaults to [null].
  hitCacheOnErrorExcept: [401, 403],
  // Overrides any HTTP directive to delete entry past this duration.
  // Useful only when origin server has no cache config or custom behaviour is desired.
  // Defaults to [null].
  maxStale: const Duration(days: 365),
  // Default. Allows 3 cache sets and ease cleanup.
  priority: CachePriority.normal,
  // Default. Body and headers encryption with your own algorithm.
  cipher: null,
  // Default. Key builder to retrieve requests.
  keyBuilder: CacheOptions.defaultCacheKeyBuilder,
  // Default. Allows to cache POST requests.
  // Overriding [keyBuilder] is strongly recommended when [true].
  allowPostMethod: false,
);

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String getVideoConfigFromPlayerVimeo() =>
      "getVideoConfigFromPlayerVimeo";
}

abstract class MyAppApi {
  Future<NetworkResponse> getVideoConfigFromPlayerVimeo(vimeoId);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getVideoConfigFromPlayerVimeo(vimeoId) async {
    return await handleNetworkError(
      proccess: () async {
        Response response = await AppClient(customInterceptors: [
          DioCacheInterceptor(options: _cacheOptions)
        ]).get(_MyAppEndpoint.getVideoConfigFromPlayerVimeo(),
            queryParameters: {'videoId': vimeoId});
        return NetworkResponse.fromResponse(response,
            converter: (json) => VimeoConfig.fromJson(json));
      },
    );
  }
}
